@@ -49,9 +49,6 @@
 #include <algorithm>
 #include "chrome/common/ipc_channel.h" // for IPC::Channel::kMaximumMessageSize
 
-#ifdef ANDROID
-#include <android/log.h>
-#endif
 #ifdef XP_WIN
 #include <windows.h>
 # if defined(SendMessage)
@@ -896,9 +893,6 @@ nsFrameMessageManager::GetChildAt(uint32_t aIndex,
 NS_IMETHODIMP
 nsFrameMessageManager::Dump(const nsAString& aStr)
 {
-#ifdef ANDROID
-  __android_log_print(ANDROID_LOG_INFO, "Gecko", "%s", NS_ConvertUTF16toUTF8(aStr).get());
-#endif
 #ifdef XP_WIN
   if (IsDebuggerPresent()) {
     OutputDebugStringW(PromiseFlatString(aStr).get());
